@@ -156,7 +156,7 @@ def main(pacts, base_url, pact_url, pact_urls, states_url, states_setup_url,
         'log_dir': log_dir,
         'log_level': log_level,
         'provider_app_version': provider_app_version,
-        'custom_provider_header': list(headers),
+        'custom_provider_headers': list(headers),
         'timeout': timeout,
         'verbose': verbose,
         'consumer_tags': list(consumer_version_tag),
